@@ -1,6 +1,7 @@
 "plot.varstabil" <-
 function(x, ...){
   K <- x$K
+  op <- par(no.readonly = TRUE)
   for(i in 1 : K){
     title <- paste(x[[1]][[i]]$type, "of equation", x[[2]][i])
     plot(x[[1]][[i]], main = title)
@@ -9,4 +10,5 @@ function(x, ...){
       readline()
     }
   }
+  par(op)
 }
